body, td {
    font: 12px verdana, arial;
}

h1 {
    font: 24px verdana, arial;
}

a:link {
    text-decoration: none;
    color: dodgerblue;
}

a:visited {
    text-decoration: none;
    color: dodgerblue;
}

a:active {
    color: dodgerblue;
}

a:hover {
    text-decoration: underline;
    color: dodgerblue;
}

#main_menu {
    list-style-type: none;
    overflow: hidden;
    margin: 20px;
    padding: 0 5px;
    border-top: 2px groove black;
    border-bottom: 2px ridge black;
}

#main_menu li {
    float: left;
    margin: 0.5em;
}

.hovertable {
    width: 600px;
}

.hovertable tbody > tr {
    background: #ffffff;
}

.hovertable tbody > tr:hover {
    background: #cecece;
}

.aligncenter {
    text-align: center;
}

.alignright {
    text-align: right;
}

.flashes {
    list-style-type: none;
}

.flashes li > span {
    background: #e04040;
    font-size: 14px;
    display: inline-block;
    border: 2px outset #e04040;
    border-radius: 5px;
    padding: 10px;
    margin-bottom: 4px;
}

.needsrestart {
    background: yellow;
}

#serverlist {
    line-height: 1.8em;
}

#serverlist_filter {
    margin: 0.5em 0;
}

#serverlist form {
    display: inline;
}

.version_number {
    position: relative;
    bottom: 35px;
}
