# basicauth.py - Flask app wrapper to provide global http basic auth
#
#  Copyright (c) 2007-2013 RobHost GmbH <support@robhost.de>
#
#  Author: Dirk Dankhoff <dd@robhost.de>
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License as
#  published by the Free Software Foundation; either version 2 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
#  USA
import os

import flask.ext.basicauth

from .. import passwd

class BasicAuth(flask.ext.basicauth.BasicAuth):
    def __init__(self, app):
        if os.path.exists(passwd.passwd_file):
            app.config['BASIC_AUTH_FORCE'] = True
        super(BasicAuth, self).__init__(app)

    def check_credentials(self, username, password):
        user = passwd.get_user_from_passwd(username)

        if user is not None:
            return passwd.hashpw(password, user[1]) == user[1]

        return False
